@@ -27,9 +27,16 @@ Filename:	display.h
 Description:	function definitions for copilot display module
 
 Update History:   (most recent first)
+     Brian Grossman 30-Jun-97 24:00 -- added pixeldoubling
      I. Curtis  25-Feb-97 21:20 -- Created.
 
 ******************************************************************************/
-char *xcpInitialize(int no_x_shm);
-void xcpEventLoop(char *sbuf, shared_img *custreg_img);
+#include <X11/Intrinsic.h>
+#include <shared.h>
 
+extern char *xcpInitialize(shared_img *shptr, XtAppContext context, Widget topWidget, int no_x_shm,
+                           int magfactor, int use_private_colormap,
+                           char *BackgroundColorName,
+                           char *BacklightColorName);
+extern void xcpEventLoop(XtAppContext context, Widget topWidget, char *sbuf,
+                         shared_img *custreg_img);
