@@ -19,4 +19,4 @@ Update History:   (most recent first)
 
 extern char *mx_popup_filesel(Display *display, int screen,
 			      mx_appearance *app,
-			      int *x, int *y);
+			      int *x, int *y, int allP);
